@@ -125,7 +125,7 @@ def opt_catboost(X_train,
                    verbose=False,
                    seed=seed,
                    early_stopping_rounds=early_stopping,
-                   folds=folds
+                   folds=folds,
                    as_pandas=True)
 
         # Metric to extract the loss from
@@ -162,7 +162,19 @@ def opt_catboost(X_train,
     return {'params':best_params, 'n':best_n}
 
 
-def opt_xgboost(X_train, y_train, cat_features=None, cv_folds=3, n_trials=20, verbose=0, params=None, device='GPU', max_rounds=5000, seed=0, early_stopping=20, figsize=(15,6)):
+def opt_xgboost(X_train,
+                y_train,
+                cat_features=None,
+                cv_folds=3,
+                folds=None,
+                n_trials=20,
+                verbose=0,
+                params=None,
+                device='GPU',
+                max_rounds=5000,
+                seed=0,
+                early_stopping=20,
+                figsize=(15,6)):
     """
     Performs n_trials using Hyperopt to obtain the best XGBoost parameters
 
@@ -214,6 +226,7 @@ def opt_xgboost(X_train, y_train, cat_features=None, cv_folds=3, n_trials=20, ve
         cv = xgb.cv(params=params,
                     dtrain=train_dmatrix,
                     nfold=cv_folds,
+                    folds=folds,
                     stratified=False,
                     metrics=params['eval_metric'],
                     verbose_eval=False,
@@ -256,7 +269,19 @@ def opt_xgboost(X_train, y_train, cat_features=None, cv_folds=3, n_trials=20, ve
     return {'params': best_params, 'n': best_n}
 
 
-def opt_lightgbm(X_train, y_train, cat_features=None, cv_folds=3, n_trials=20, verbose=0, params=None, device='CPU', max_rounds=5000, seed=0, early_stopping=20, figsize=(15,6)):
+def opt_lightgbm(X_train,
+                 y_train,
+                 cat_features=None,
+                 cv_folds=3,
+                 folds=None,
+                 n_trials=20,
+                 verbose=0,
+                 params=None,
+                 device='CPU',
+                 max_rounds=5000,
+                 seed=0,
+                 early_stopping=20,
+                 figsize=(15,6)):
     """
     Performs n_trials using Hyperopt to obtain the best LightGBM parameters
 
@@ -307,6 +332,7 @@ def opt_lightgbm(X_train, y_train, cat_features=None, cv_folds=3, n_trials=20, v
         cv = lgb.cv(params=params,
                     train_set=dataset,
                     nfold=cv_folds,
+                    folds=folds,
                     stratified=False,
                     verbose_eval=False,
                     seed=seed,
@@ -321,7 +347,7 @@ def opt_lightgbm(X_train, y_train, cat_features=None, cv_folds=3, n_trials=20, v
 
         if verbose > 0:
             print('Test Loss: %0.4f RMSE with %d iterations. Time elapsed %s' % (
-            loss, best_iteration, str(round(time.time() - start,2))))
+            loss, best_iteration, str(round(time.time() - start, 2))))
 
         val = {'loss': loss,  # mandatory
                'status': STATUS_OK,  # mandatory
@@ -331,11 +357,11 @@ def opt_lightgbm(X_train, y_train, cat_features=None, cv_folds=3, n_trials=20, v
 
     trials = Trials()
     hyperopt_lgb = fmin(fn=objective,
-                       space=HYPEROPT_PARAMS,
-                       algo=tpe.suggest,
-                       verbose=True if verbose > 0 else False,
-                       max_evals=n_trials,
-                       trials=trials)
+                        space=HYPEROPT_PARAMS,
+                        algo=tpe.suggest,
+                        verbose=True if verbose > 0 else False,
+                        max_evals=n_trials,
+                        trials=trials)
 
     best_params, best_n = _get_best_params(hyperopt_lgb, HYPEROPT_PARAMS, INTEGER_PARAMS_LIST, trials)
     # apparently hyperopt has a bug on choice methods
@@ -347,4 +373,4 @@ def opt_lightgbm(X_train, y_train, cat_features=None, cv_folds=3, n_trials=20, v
     if verbose == 2:
         _evaluation_plot(trials.losses(), figsize=figsize)
 
-    return {'params': best_params, 'n': best_n}
\ No newline at end of file
+    return {'params': best_params, 'n': best_n}
